<?php namespace EwTools\Admin;

use EwTools\Support\Collection;

/**
 * MessageBag
 *
 * @link    http://infomaker.se
 * @package EwTools\Admin
 * @since   EwTools\Admin\MessageBag 0.1
 */
class MessageBag {
    
    /**
     * Contains all added messages
     *
     * @var Collection
     */
    private $messages;
    
    /**
     * Instance of self
     *
     * @var self
     */
    private static $instance;
    
    /**
     * MessageBag constructor.
     *
     * @since 0.1
     */
    private function __construct() {
        $this->messages = new Collection();
    }
    
    /**
     * Add message to the bag
     *
     * @param Message $message
     *
     * @since 0.1
     * @return void
     */
    private function addMessage( Message $message ) {
        $this->messages->push($message);
    }
    
    /**
     * Retrieve all messages
     *
     * @since 0.1
     * @return Collection
     */
    public function getMessages() {
        return $this->messages;
    }
    
    private static function getInstance() {
        if ( static::$instance === null ) {
            static::$instance = new static();
        }
        return static::$instance;
    }
    
    /**
     * @param Message $message
     *
     * @since 0.1
     * @return void
     */
    public static function add( Message $message ) {
        static::getInstance()->addMessage($message);
    }
    
    /**
     * Generate html out of every message in the bag
     *
     * @since 0.1
     * @return mixed
     */
    public static function messagesToHtml() {
        return implode('', static::getInstance()->getMessages()->map(function(Message $message) {
            return $message->toHtml();
        })->toArray());
    }
    
    /**
     * Render the generated html from every message in the bag
     *
     * @since 0.1
     * @return void
     */
    public static function renderMessages() {
        echo static::messagesToHtml();
    }
}