<?php namespace EwTools\Models;

use AbstractOcObject;
use EveryBoard_Renderer;
use EwTools\Interfaces\Support\Selectable;
use EwTools\Support\Str;

/**
 * Everyboard
 *
 * @property mixed id
 * @link    http://infomaker.se
 * @package EwTools\Models
 * @since   EwTools\Models\Everyboard 0.1
 */
class Everyboard extends Post implements Selectable {
    
    protected static $type = 'everyboard';
    
    /**
     * Adds articles to the filter used by content containers.
     *
     * @param array $objects
     *
     * @return Everyboard
     * @since 0.1
     */
    public function fillContentContainers( array $objects = [] ) {
        add_filter( 'ew_content_container_fill', function ( $arr ) use ( $objects ) {
            return array_merge( $arr, $objects );
        } );
        
        return $this;
    }
    
    /**
     * Retrieve the content of the board in the form of an array or json string if specified
     *
     * @param bool $to_array
     *
     * @since 0.1
     * @return array|string
     */
    public function boardContent( $to_array = false ) {
        $content = $this->getMeta( 'everyboard_json', [] );
        
        if(! is_array( $content ) && $to_array ) {
            return Str::notEmpty( $content ) ? json_decode( $content, true ) : [];
        }
        
        if (! $to_array ) {
            return !empty( $content ) ? json_encode( $content ) : '';
        }
        
        return $content;
    }
    
    /**
     * Return data in the form of an array fit for a select-box
     * A preselected value may be sent in.
     *
     * @param mixed $selected
     *
     * @since 0.1
     * @return array
     */
    public static function toSelect( $selected = null ) {
        return static::all()->map( function ( self $board ) use ( $selected ) {
            return [
                'value'    => $board->id,
                'text'     => $board->title(),
                'selected' => $board->id === $selected
            ];
        } )->toArray();
    }
    
    /**
     * Fetches the board json and returns it as raw html.
     *
     * @since 0.1
     *
     * @param array $objects
     *
     * @return string
     */
    public function generate( array $objects = [] ) {
        if( ! empty( $objects ) ) {
            $this->fillContentContainers( $objects );
        }
        
        return ( new EveryBoard_Renderer() )->render( [ $this->boardContent() ] );
    }
}