<?php namespace EwTools;

use EwTools\Interfaces\PluginConfigInterface;
use EwTools\Support\Str;

/**
 * ProjectPluginConfig
 *
 * @link    http://infomaker.se
 * @package EwTools
 * @since   EwTools\ProjectPluginConfig 0.1
 */
abstract class ProjectPluginConfig implements PluginConfigInterface {
    
    /**
     * Name of the plugin
     *
     * @var string
     */
    protected $name = '';
    
    /**
     * Slug of the plugin
     *
     * @var string
     */
    protected $slug = '';
    
    /**
     * The name of the project-plugin folder
     *
     * @var string
     */
    protected $path = '';
    
    /**
     * Retrieve the name of the project plugin
     *
     * @since 0.1
     * @return string
     */
    public function getName() {
        return $this->name;
    }
    
    /**
     * Get the project slug
     *
     * @since 0.1
     * @return string
     */
    public function getSlug() {
        return $this->slug;
    }
    
    /**
     * Get the folder-name project-plugin
     *
     *
     * @param string $file
     *
     * @since 0.1
     * @return string
     */
    public function getPath( $file='' ) {
        return Str::notEmpty($file) ? Str::append($file, $this->path, '/') : $this->path;
    }
}